<?php
/**
 * @package Deltadromeus_Email_Checker
 * @version 1.1
 */
/*
Plugin Name: Deltadromeus Email Checker
Description: Easily add your custom Deltadromeus Email Checker script URL to your website in order to use Email Checker service. To get started: activate the Deltadromeus Email Checker plugin and then go to your Email Checker Settings page to set up your script URL.
Author: deltadromeus
Version: 1.1
Author URI: https://www.deltadromeus.com/
Text Domain: deltadromeus-email-checker
Domain Path: /languages
*/

// Make sure we don't expose any info if called directly
if ( !function_exists( 'add_action' ) ) {
	echo 'Hi there!  I\'m just a plugin, not much I can do when called directly.';
	exit;
}

class Deltadromeus_Email_Checker_Service
{
	public function __construct()
	{
		add_action( 'wp_enqueue_scripts',  array( $this, 'deltadromeus_email_checker_add_script' ) );
	}

	public function deltadromeus_email_checker_add_script()
	{
		$options = get_option( 'deltadromeus_email_checker_options' );
		if ( $options && isset( $options['script_url'] ) && $options['service_enabled'] != 'no' ){
			wp_enqueue_script( 'deltadromeus-email-checker-flex', $options['script_url'], array(), null, true);
		}
	}

}

class Deltadromeus_Email_Checker_Setting_Page
{
    /**
     * Holds the values to be used in the fields callbacks
     */
    private $options;

    /**
     * Start up
     */
    public function __construct()
    {
				add_action( 'plugins_loaded', array( $this , 'load_plugin_textdomain' ) );
        add_action( 'admin_menu', array( $this, 'add_plugin_page' ) );
        add_action( 'admin_init', array( $this, 'page_init' ) );
    }

    /**
     * Add options page
     */
    public function add_plugin_page()
    {
        // This page will be under "Settings"
        add_options_page(
            __('Deltadromeus Email Checker - Settings', 'deltadromeus-email-checker'),
            'Email Checker',
            'manage_options',
            'deltadromeus-email-checker-settings-admin',
            array( $this, 'create_admin_page' )
        );
    }

    /**
     * Options page callback
     */
    public function create_admin_page()
    {
        // Set class property
        $this->options = get_option( 'deltadromeus_email_checker_options' );
        ?>
        <div class="wrap">
            <h1><?php _e('Deltadromeus Email Checker - Settings', 'deltadromeus-email-checker') ?></h1>
            <form method="post" action="options.php">
            <?php
                // This prints out all hidden setting fields
                settings_fields( 'deltadromeus_email_checker_options_group' );
                do_settings_sections( 'deltadromeus-email-checker-settings-admin' );
                submit_button();
            ?>
            </form>
        </div>
        <?php
    }

    /**
     * Register and add settings
     */
    public function page_init()
    {
        register_setting(
            'deltadromeus_email_checker_options_group', // Option group
            'deltadromeus_email_checker_options', // Option name
            array( $this, 'sanitize' ) // Sanitize
        );

        add_settings_section(
            'deltadromeus_email_checker_options_section', // ID
            __('My Settings', 'deltadromeus-email-checker'), // Title
            array( $this, 'print_section_info' ), // Callback
            'deltadromeus-email-checker-settings-admin' // Page
        );

        add_settings_field(
            'script_url', // ID
            __('Script URL', 'deltadromeus-email-checker'), // Title
            array( $this, 'script_url_callback' ), // Callback
            'deltadromeus-email-checker-settings-admin', // Page
            'deltadromeus_email_checker_options_section' // Section
        );

				add_settings_field(
            'service_enabled', // ID
            __('Enable email addresses verifications', 'deltadromeus-email-checker'), // Title
            array( $this, 'service_enabled_callback' ), // Callback
            'deltadromeus-email-checker-settings-admin', // Page
            'deltadromeus_email_checker_options_section' // Section
        );

    }

    /**
     * Sanitize each setting field as needed
     *
     * @param array $input Contains all settings fields as array keys
     */
    public function sanitize( $input )
    {
        $new_input = array();
        if( isset( $input['script_url'] ) )
            $new_input['script_url'] = sanitize_text_field( $input['script_url'] );
				if( isset( $input['service_enabled'] ) )
            $new_input['service_enabled'] = sanitize_text_field( $input['service_enabled'] );

        return $new_input;
    }

    /**
     * Print the Section text
     */
    public function print_section_info()
    {
				printf(__('<p>First, you need a <a href="%s" target="_blank">Deltadromeus Email Checker</a> account. Once <a href="%s" target="_blank">logged in</a> your account, copy your script url and paste it below.</p>', 'deltadromeus-email-checker'), 'https://www.deltadromeus.com/', 'https://www.deltadromeus.com/login');
        printf(__('Enter your script URL below:', 'deltadromeus-email-checker'));
    }

    /**
     * Get the settings option array and print one of its values
     */
    public function script_url_callback()
    {
        printf(
            '<input type="url" id="script_url" name="deltadromeus_email_checker_options[script_url]" value="%s" class="regular-text" />',
            isset( $this->options['script_url'] ) ? esc_attr( $this->options['script_url'] ) : ''
        );
    }

		public function service_enabled_callback()
		{
				$service_enabled = !isset( $this->options['service_enabled'] ) || $this->options['service_enabled'] == 'yes';
				printf(
						'<input type="radio" id="service_enabled" name="deltadromeus_email_checker_options[service_enabled]" value="yes"' . ( $service_enabled ? ' checked' : '') . ' />&nbsp;'.__('Yes', 'deltadromeus-email-checker').'&nbsp;&nbsp;&nbsp;' . '<input type="radio" id="service_enabled" name="deltadromeus_email_checker_options[service_enabled]" value="no"' . ( !$service_enabled ? ' checked' : '') . ' />&nbsp;'.__('No', 'deltadromeus-email-checker')
				);
		}

		public function load_plugin_textdomain() {
			load_plugin_textdomain( 'deltadromeus-email-checker', FALSE, basename( dirname( __FILE__ ) ) . '/languages/' );
		}
}

if ( is_admin() ){ // admin actions
  $deltadromeus_email_checker_setting_page = new Deltadromeus_Email_Checker_Setting_Page();
} else { // public actions
  $deltadromeus_email_checker_service = new Deltadromeus_Email_Checker_Service();
}

?>
